function _aws_cdk_aws_fsx_LustreDeploymentType(p) {
}
function _aws_cdk_aws_fsx_Weekday(p) {
}
function _aws_cdk_aws_fsx_IFileSystem(p) {
}
function _aws_cdk_aws_fsx_LustreMaintenanceTimeProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.day))
        _aws_cdk_aws_fsx_Weekday(p.day);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_fsx_LustreMaintenanceTime(p) {
}
function _aws_cdk_aws_fsx_FileSystemAttributes(p) {
}
function _aws_cdk_aws_fsx_LustreConfiguration(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.deploymentType))
        _aws_cdk_aws_fsx_LustreDeploymentType(p.deploymentType);
    if (!visitedObjects.has(p.weeklyMaintenanceStartTime))
        _aws_cdk_aws_fsx_LustreMaintenanceTime(p.weeklyMaintenanceStartTime);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_fsx_FileSystemBase(p) {
}
function _aws_cdk_aws_fsx_LustreFileSystemProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.lustreConfiguration))
        _aws_cdk_aws_fsx_LustreConfiguration(p.lustreConfiguration);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_fsx_LustreFileSystem(p) {
}
function _aws_cdk_aws_fsx_FileSystemProps(p) {
}
function _aws_cdk_aws_fsx_CfnFileSystemProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.lustreConfiguration))
        _aws_cdk_aws_fsx_CfnFileSystem_LustreConfigurationProperty(p.lustreConfiguration);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_fsx_CfnFileSystem(p) {
}
function _aws_cdk_aws_fsx_CfnFileSystem_AuditLogConfigurationProperty(p) {
}
function _aws_cdk_aws_fsx_CfnFileSystem_DiskIopsConfigurationProperty(p) {
}
function _aws_cdk_aws_fsx_CfnFileSystem_SelfManagedActiveDirectoryConfigurationProperty(p) {
}
function _aws_cdk_aws_fsx_CfnFileSystem_LustreConfigurationProperty(p) {
}
function _aws_cdk_aws_fsx_CfnFileSystem_OntapConfigurationProperty(p) {
}
function _aws_cdk_aws_fsx_CfnFileSystem_WindowsConfigurationProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_fsx_LustreDeploymentType, _aws_cdk_aws_fsx_Weekday, _aws_cdk_aws_fsx_IFileSystem, _aws_cdk_aws_fsx_LustreMaintenanceTimeProps, _aws_cdk_aws_fsx_LustreMaintenanceTime, _aws_cdk_aws_fsx_FileSystemAttributes, _aws_cdk_aws_fsx_LustreConfiguration, _aws_cdk_aws_fsx_FileSystemBase, _aws_cdk_aws_fsx_LustreFileSystemProps, _aws_cdk_aws_fsx_LustreFileSystem, _aws_cdk_aws_fsx_FileSystemProps, _aws_cdk_aws_fsx_CfnFileSystemProps, _aws_cdk_aws_fsx_CfnFileSystem, _aws_cdk_aws_fsx_CfnFileSystem_AuditLogConfigurationProperty, _aws_cdk_aws_fsx_CfnFileSystem_DiskIopsConfigurationProperty, _aws_cdk_aws_fsx_CfnFileSystem_SelfManagedActiveDirectoryConfigurationProperty, _aws_cdk_aws_fsx_CfnFileSystem_LustreConfigurationProperty, _aws_cdk_aws_fsx_CfnFileSystem_OntapConfigurationProperty, _aws_cdk_aws_fsx_CfnFileSystem_WindowsConfigurationProperty };
module.exports.DeprecationError = DeprecationError;
